@@ -1,10 +1,10 @@
 /* A Scheme reader compiler for Guile.
 
-   Copyright (C) 2005, 2006, 2007, 2008  Ludovic Courts <ludo@gnu.org>
+   Copyright (C) 2005, 2006, 2007, 2008, 2012  Ludovic Courts <ludo@gnu.org>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -1541,9 +1541,8 @@ scm_c_make_reader (void *code_buffer,
 
 #else /* SCM_READER_USE_LIGHTNING */
 
-/* The slow Lightning-free implementation of `scm_c_make_reader ()' and
-   `scm_call_reader ()'.  */
-#warning "Compiling the slow, Lightning-free, implementation!"
+/* The lightning-free implementation of `scm_c_make_reader' and
+   `scm_call_reader'.  */
 
 struct scm_reader
 {
@@ -1677,14 +1676,14 @@ scm_call_reader (scm_reader_t reader, SCM port, int caller_handled,
 		 scm_reader_t top_level_reader)
 #define FUNC_NAME "%call-reader"
 {
-  int c = 0;
+  scm_t_wchar c = 0;
   scm_token_reader_spec_t *tr;
   SCM result = SCM_UNSPECIFIED;
 
-  if (port == SCM_UNDEFINED)
+  if (SCM_UNBNDP (port))
     port = scm_current_input_port ();
-  else
-    SCM_VALIDATE_PORT (2, port);
+
+  SCM_VALIDATE_PORT (2, port);
 
  doit:
   while (1)
@@ -2010,9 +2009,10 @@ SCM_DEFINE (scm_make_reader, "make-reader", 1, 1, 1,
   scm_token_reader_spec_t *c_specs;
 
   SCM_VALIDATE_LIST (1, token_readers);
-  if ((fault_handler_proc == SCM_UNDEFINED)
-      || (fault_handler_proc == SCM_BOOL_F))
-    fault_handler_proc = scm_reader_standard_fault_handler_proc;
+  if (SCM_UNBNDP (fault_handler_proc)
+      || fault_handler_proc == SCM_BOOL_F)
+    fault_handler_proc =
+      scm_variable_ref (scm_reader_standard_fault_handler_var);
   else
     SCM_VALIDATE_PROC (2, fault_handler_proc);
 
@@ -2059,7 +2059,7 @@ SCM_DEFINE (scm_make_reader, "make-reader", 1, 1, 1,
 				  &actual_size);
       if (!reader)
 	{
-	  debug ("%s: reader too small (%u vs. %u)\n",
+	  debug ("%s: reader too small (%zi vs. %zi)\n",
 		 __FUNCTION__, code_size, actual_size);
 	  code_size <<= 1;
 	  code_buffer = scm_realloc (code_buffer, code_size);
@@ -2094,7 +2094,7 @@ SCM_DEFINE (scm_make_token_reader, "make-token-reader", 2, 1, 0,
   if (proc != SCM_BOOL_F)
     SCM_VALIDATE_PROC (2, proc);
 
-  if (escape_p == SCM_UNDEFINED)
+  if (SCM_UNBNDP (escape_p))
     escape_p = SCM_BOOL_F;
   else
     SCM_VALIDATE_BOOL (3, escape_p);
@@ -2169,12 +2169,20 @@ SCM_DEFINE (scm_standard_token_reader, "standard-token-reader", 1, 0, 0,
 	    "reader, then an error is raised.")
 #define FUNC_NAME "standard-token-reader"
 {
-  SCM s_token_reader;
+  SCM s_token_reader, s_name_str;
   const scm_token_reader_spec_t *spec;
+  size_t c_name_len;
+  char *c_name;
 
   SCM_VALIDATE_SYMBOL (1, name);
 
-  spec = scm_token_reader_lookup (scm_i_symbol_chars (name));
+  s_name_str = scm_symbol_to_string (name);
+  c_name_len = scm_c_string_length (s_name_str);
+  c_name = (char *) alloca (c_name_len + 1);
+  (void) scm_to_locale_stringbuf (s_name_str, c_name, c_name_len);
+  c_name[c_name_len] = '\0';
+
+  spec = scm_token_reader_lookup (c_name);
   if (!spec)
     {
       scm_misc_error (FUNC_NAME, "not a standard token reader: ~A",
@@ -2569,8 +2577,8 @@ token_reader_proc_apply (SCM tr_proc, SCM chr, SCM port, SCM reader)
 
 
 
-/* The standard fault handler proc.  */
-SCM scm_reader_standard_fault_handler_proc = SCM_BOOL_F;
+/* A variable holding the standard fault handler proc.  */
+SCM scm_reader_standard_fault_handler_var = SCM_BOOL_F;
 
 SCM_DEFINE (scm_reader_standard_fault_handler,
 	    "%reader-standard-fault-handler", 3, 0, 0,
@@ -2610,13 +2618,10 @@ scm_reader_init_bindings (void)
 
 #include "reader.x"
 
-  scm_reader_standard_fault_handler_proc =
-    SCM_VARIABLE_REF (scm_c_lookup ("%reader-standard-fault-handler"));
+  scm_reader_standard_fault_handler_var =
+    scm_c_lookup ("%reader-standard-fault-handler");
 
   /* Initialize the other subsystems.  */
   scm_initialize_token_reader_library ();
   scm_initialize_reader_library ();
-
-  /* Compile the standard reader.  */
-  scm_load_standard_reader ();
 }
